==> ogre_1.7.4+dfsg1.orig.tar.xz: ogre-1.7.4+dfsg1/PlugIns/OctreeSceneManager/src/OgreOctreePlugin.cpp <==
/*
-----------------------------------------------------------------------------
This source file is part of OGRE
(Object-oriented Graphics Rendering Engine)
For the latest info, see http://www.ogre3d.org/

Copyright (c) 2000-2011 Torus Knot Software Ltd

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
-----------------------------------------------------------------------------
*/

#include "OgreOctreePlugin.h"
#include "OgreRoot.h"

namespace Ogre 
{
	const String sPluginName = "Octree & Terrain Scene Manager";
	//---------------------------------------------------------------------
	OctreePlugin::OctreePlugin()
		:mOctreeSMFactory(0), mTerrainSMFactory(0), mTerrainPSListenerManager(0)
	{

	}
	//---------------------------------------------------------------------
	const String& OctreePlugin::getName() const
	{
		return sPluginName;
	}
	//---------------------------------------------------------------------
	void OctreePlugin::install()
	{
		// Create objects
		mOctreeSMFactory = OGRE_NEW OctreeSceneManagerFactory();
		mTerrainSMFactory = OGRE_NEW TerrainSceneManagerFactory();
		mTerrainPSListenerManager = OGRE_NEW TerrainPageSourceListenerManager();

	}
	//---------------------------------------------------------------------
	void OctreePlugin::initialise()
	{
		// Register
		Root::getSingleton().addSceneManagerFactory(mOctreeSMFactory);
		Root::getSingleton().addSceneManagerFactory(mTerrainSMFactory);
	}
	//---------------------------------------------------------------------
	void OctreePlugin::shutdown()
	{
		// Unregister
		Root::getSingleton().removeSceneManagerFactory(mTerrainSMFactory);
		Root::getSingleton().removeSceneManagerFactory(mOctreeSMFactory);
	}
	//---------------------------------------------------------------------
	void OctreePlugin::uninstall()
	{
		// destroy 
		OGRE_DELETE mTerrainPSListenerManager;
		mTerrainPSListenerManager = 0;
		OGRE_DELETE mTerrainSMFactory;
		mTerrainSMFactory = 0;
		OGRE_DELETE mOctreeSMFactory;
		mOctreeSMFactory = 0;


	}


}

==> ogre-1.9_1.9.0+dfsg1.orig.tar.xz: ogre-1.9.0/PlugIns/OctreeSceneManager/src/OgreOctreePlugin.cpp <==
/*
-----------------------------------------------------------------------------
This source file is part of OGRE
(Object-oriented Graphics Rendering Engine)
For the latest info, see http://www.ogre3d.org/

Copyright (c) 2000-2013 Torus Knot Software Ltd

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
-----------------------------------------------------------------------------
*/

#include "OgreOctreePlugin.h"
#include "OgreRoot.h"

namespace Ogre 
{
	const String sPluginName = "Octree Scene Manager";
	//---------------------------------------------------------------------
	OctreePlugin::OctreePlugin()
		:mOctreeSMFactory(0)
	{

	}
	//---------------------------------------------------------------------
	const String& OctreePlugin::getName() const
	{
		return sPluginName;
	}
	//---------------------------------------------------------------------
	void OctreePlugin::install()
	{
		// Create objects
		mOctreeSMFactory = OGRE_NEW OctreeSceneManagerFactory();

	}
	//---------------------------------------------------------------------
	void OctreePlugin::initialise()
	{
		// Register
		Root::getSingleton().addSceneManagerFactory(mOctreeSMFactory);
	}
	//---------------------------------------------------------------------
	void OctreePlugin::shutdown()
	{
		// Unregister
		Root::getSingleton().removeSceneManagerFactory(mOctreeSMFactory);
	}
	//---------------------------------------------------------------------
	void OctreePlugin::uninstall()
	{
		// destroy 
		OGRE_DELETE mOctreeSMFactory;
		mOctreeSMFactory = 0;


	}


}
